@@ -3,11 +3,14 @@
 #' `roc_auc()` is a metric that computes the area under the ROC curve. See
 #' [roc_curve()] for the full curve.
 #'
-#' For most methods, `roc_auc()` makes no effort to ensure that the supplied
-#' class probabilities result in a AUC value above `0.5` (random guessing).
+#' For most methods, `roc_auc()` defaults to allowing `pROC::roc()` control
+#' the direction of the computation, but allows you to control this by passing
+#' `options = list(direction = "<")` or any other allowed direction value.
 #' However, the Hand, Till (2001) method assumes that the individual AUCs are
 #' all above `0.5`, so if an AUC value below `0.5` is computed, then `1` is
-#' subtracted from it to get the correct result.
+#' subtracted from it to get the correct result. When not using the Hand, Till
+#' method, pROC advises setting the `direction` when doing resampling so that
+#' the AUC values are not biased upwards.
 #'
 #' Generally, an ROC AUC value is between `0.5` and `1`, with `1` being a
 #' perfect prediction model. If your value is between `0` and `0.5`, then
@@ -33,7 +36,7 @@
 #'
 #' @param options A `list` of named options to pass to [pROC::roc()]
 #' such as `direction` or `smooth`. These options should not include `response`,
-#' `predictor`, or `levels`.
+#' `predictor`, `levels`, or `quiet`.
 #'
 #' @param estimator One of `"binary"`, `"hand_till"`, `"macro"`, or
 #' `"macro_weighted"` to specify the type of averaging to be done. `"binary"`
@@ -60,11 +63,19 @@
 #'
 #' @author Max Kuhn
 #'
-#' @template examples-prob
+#' @template examples-binary-prob
+#' @template examples-multiclass-prob
 #' @examples
-#' # passing options via a list and _not_ `...`
-#' roc_auc(two_class_example, truth = truth, Class1,
-#'         options = list(smooth = TRUE))
+#' # ---------------------------------------------------------------------------
+#' # Options for `pROC::roc()`
+#'
+#' # Pass options via a named list and not through `...`!
+#' roc_auc(
+#'   two_class_example,
+#'   truth = truth,
+#'   Class1,
+#'   options = list(smooth = TRUE)
+#' )
 #'
 #' @export
 roc_auc <- function(data, ...) {
@@ -72,6 +83,7 @@ roc_auc <- function(data, ...) {
 }
 
 class(roc_auc) <- c("prob_metric", "function")
+attr(roc_auc, "direction") <- "maximize"
 
 #' @export
 #' @rdname roc_auc
@@ -148,13 +160,11 @@ roc_auc_binary <- function(truth, estimate, options) {
     lvl <- lvl_values
   }
 
-  args <- quos(response = truth, predictor = estimate, levels = lvl)
+  args <- quos(response = truth, predictor = estimate, levels = lvl, quiet = TRUE)
 
-  curv <- eval_tidy(call2("roc", !!! args, !!! options, .ns = "pROC"))
+  pROC_auc <- eval_tidy(call2("auc", !!! args, !!! options, .ns = "pROC"))
 
-  res <- unname(pROC::auc(curv))
-
-  as.numeric(res)
+  as.numeric(pROC_auc)
 
 }
 
